@@ -1,10 +1,29 @@
-//---------------------------------------------------------------------------
-//
-// amorbubble.h
-//
-// Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
-//
+/* amorbubble.h
+**
+** Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
+**
+*/
 
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 #ifndef AMORBUBBLE_H
 #define AMORBUBBLE_H
 
@@ -33,6 +52,8 @@ public:
     void setOrigin(int x, int y) { mOriginX = x; mOriginY = y; }
     void setMessage(const QString& message);
 
+    bool mouseWithin() { return mMouseWithin; }    
+
 protected:
     enum VertPos { Top, Bottom };
     enum HorzPos { Left, Right };
@@ -52,7 +73,8 @@ protected:
     VertPos mArrowVert;         // vertical position of the arrow
     HorzPos mArrowHorz;         // horizontal position of the arrow
     QTextBrowser *mBrowser;	// displays the message
-    QTimer *mBubbleTimer;	// hide timer
+
+    bool mMouseWithin;		// the mouse pointer is inside the bubble
 };
 
 #endif // AMORBUBBLE_H
